==> flutter_firecache-0.0.1.tar.gz: lib/src/builders/collection_builder.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter_firecache/src/utils/map_helper.dart';

import '../query_state.dart';
import 'collection_command_builders.dart';
import 'collection_query_builders.dart';

class CollectionQueryBuilder<C, D> {
  final QueryState queryState;

  CollectionQueryBuilder(this.queryState);

  Stream<Map<String, dynamic>> getIdMap(String id) {
    return collectionQueryGetId(this.queryState, id);
  }

  Stream<T> getId<T>(
    String id,
    JsonMapper<T> jsonMapper,
  ) {
    return collectionQueryGetId(this.queryState, id)
        .map((json) => jsonMapper(json));
  }

  Stream<T> getIdSnap<T>(
    String id,
    JsonMapper<T> jsonMapper,
  ) {
    return collectionQueryGetIdSnap(this.queryState, id)
        .map((json) => jsonMapper(json));
  }

  Stream<List<T>> getAllDocs<T>(
    JsonMapper<T> jsonMapper, {
    QueryFn? whereQuery,
  }) {
    return collectionQueryGetAllDocs(this.queryState, whereQuery).map(
      (listData) => listData
          .map(
            (json) => jsonMapper(json),
          )
          .toList(),
    );
  }

  Stream<List<T>> getAllDocsSnap<T>(
    JsonMapper<T> jsonMapper, {
    QueryFn? whereQuery,
  }) {
    return collectionQueryGetAllDocsSnap(this.queryState, whereQuery).map(
      (listData) => listData
          .map(
            (json) => jsonMapper(json),
          )
          .toList(),
    );
  }

  Stream<List<Map<String, dynamic>>> getAllDocsMap({
    QueryFn? whereQuery,
  }) {
    return collectionQueryGetAllDocs(this.queryState, whereQuery);
  }

  Future<void> update(String id, Map<String, dynamic> obj, [merge = true]) {
    return collectionCommandUpdate(this.queryState, id, obj, merge);
  }

  Future<DocumentReference> add(Map<String, dynamic> obj) {
    return collectionCommandAdd(this.queryState, obj);
  }

  Future<void> delete(String id) {
    return collectionCommandDelete(this.queryState, id);
  }

  CollectionQueryBuilder overrideAppState(Map<String, dynamic> overridenState) {
    this.queryState.overrideAppState(overridenState);
    return this;
  }
}

==> flutter_firecache-0.0.2.tar.gz: lib/src/builders/collection_builder.dart <==
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:flutter_firecache/src/utils/map_helper.dart';

import '../query_state.dart';
import 'collection_command_builders.dart';
import 'collection_query_builders.dart';

class CollectionQueryBuilder {
  final QueryState queryState;

  CollectionQueryBuilder(this.queryState);

  Stream<Map<String, dynamic>> getIdMap(String id) {
    return collectionQueryGetId(this.queryState, id);
  }

  Stream<T> getId<T>(
    String id,
    JsonMapper<T> jsonMapper,
  ) {
    return collectionQueryGetId(this.queryState, id)
        .map((json) => jsonMapper(json));
  }

  Stream<T> getIdSnap<T>(
    String id,
    JsonMapper<T> jsonMapper,
  ) {
    return collectionQueryGetIdSnap(this.queryState, id)
        .map((json) => jsonMapper(json));
  }

  Stream<List<T>> getAllDocs<T>(
    JsonMapper<T> jsonMapper, {
    QueryFn? whereQuery,
  }) {
    return collectionQueryGetAllDocs(this.queryState, whereQuery).map(
      (listData) => listData
          .map(
            (json) => jsonMapper(json),
          )
          .toList(),
    );
  }

  Stream<List<T>> getAllDocsSnap<T>(
    JsonMapper<T> jsonMapper, {
    QueryFn? whereQuery,
  }) {
    return collectionQueryGetAllDocsSnap(this.queryState, whereQuery).map(
      (listData) => listData
          .map(
            (json) => jsonMapper(json),
          )
          .toList(),
    );
  }

  Stream<List<Map<String, dynamic>>> getAllDocsMap({
    QueryFn? whereQuery,
  }) {
    return collectionQueryGetAllDocs(this.queryState, whereQuery);
  }

  Future<void> update(String id, Map<String, dynamic> obj, [merge = true]) {
    return collectionCommandUpdate(this.queryState, id, obj, merge);
  }

  Future<DocumentReference> add(Map<String, dynamic> obj) {
    return collectionCommandAdd(this.queryState, obj);
  }

  Future<void> delete(String id) {
    return collectionCommandDelete(this.queryState, id);
  }

  CollectionQueryBuilder overrideAppState(Map<String, dynamic> overridenState) {
    this.queryState.overrideAppState(overridenState);
    return this;
  }
}
